import React, { useState, useEffect } from 'react'

const products = [
  {
    id: 1,
    name: 'Studio Logo T-Shirt',
    price: 29.99,
    category: 'apparel',
    image: '/api/placeholder/400/400',
    description: 'Premium cotton t-shirt with embroidered studio logo',
    sizes: ['S', 'M', 'L', 'XL', 'XXL'],
    colors: ['Black', 'White', 'Gray'],
    inStock: true
  },
  {
    id: 2,
    name: 'Aftercare Kit',
    price: 24.99,
    category: 'care',
    image: '/api/placeholder/400/400',
    description: 'Complete aftercare package with healing ointment and instructions',
    inStock: true
  },
  {
    id: 3,
    name: 'Flash Art Print Set',
    price: 39.99,
    category: 'prints',
    image: '/api/placeholder/400/400',
    description: 'Set of 6 high-quality prints featuring original flash designs',
    sizes: ['8x10', '11x14'],
    inStock: true
  },
  {
    id: 4,
    name: 'Studio Hoodie',
    price: 54.99,
    category: 'apparel',
    image: '/api/placeholder/400/400',
    description: 'Comfortable pullover hoodie with screen-printed design',
    sizes: ['S', 'M', 'L', 'XL', 'XXL'],
    colors: ['Black', 'Gray'],
    inStock: true
  },
  {
    id: 5,
    name: 'Gift Card - $100',
    price: 100.00,
    category: 'gift-cards',
    image: '/api/placeholder/400/400',
    description: 'Perfect gift for tattoo enthusiasts. Never expires.',
    inStock: true
  },
  {
    id: 6,
    name: 'Tattoo Care Balm',
    price: 16.99,
    category: 'care',
    image: '/api/placeholder/400/400',
    description: 'Natural healing balm for tattoo aftercare and maintenance',
    inStock: true
  },
  {
    id: 7,
    name: 'Artist Collaboration Print',
    price: 49.99,
    category: 'prints',
    image: '/api/placeholder/400/400',
    description: 'Limited edition print by featured guest artist',
    sizes: ['11x14', '16x20'],
    inStock: false
  },
  {
    id: 8,
    name: 'Studio Tote Bag',
    price: 19.99,
    category: 'accessories',
    image: '/api/placeholder/400/400',
    description: 'Durable canvas tote with minimalist studio branding',
    inStock: true
  },
  {
    id: 9,
    name: 'Gift Card - $250',
    price: 250.00,
    category: 'gift-cards',
    image: '/api/placeholder/400/400',
    description: 'Premium gift card for larger tattoo projects',
    inStock: true
  },
  {
    id: 10,
    name: 'Numbing Cream',
    price: 22.99,
    category: 'care',
    image: '/api/placeholder/400/400',
    description: 'Professional-grade topical numbing cream (consult artist before use)',
    inStock: true
  },
  {
    id: 11,
    name: 'Studio Pin Set',
    price: 12.99,
    category: 'accessories',
    image: '/api/placeholder/400/400',
    description: 'Collectible enamel pin set featuring studio designs',
    inStock: true
  },
  {
    id: 12,
    name: 'Gift Card - $500',
    price: 500.00,
    category: 'gift-cards',
    image: '/api/placeholder/400/400',
    description: 'Ultimate gift card for major tattoo projects',
    inStock: true
  }
]

const categories = [
  { id: 'all', name: 'All Products' },
  { id: 'apparel', name: 'Apparel' },
  { id: 'prints', name: 'Art Prints' },
  { id: 'care', name: 'Aftercare' },
  { id: 'accessories', name: 'Accessories' },
  { id: 'gift-cards', name: 'Gift Cards' }
]

function Shop() {
  const [isLoaded, setIsLoaded] = useState(false)
  const [selectedCategory, setSelectedCategory] = useState('all')
  const [cart, setCart] = useState([])
  const [selectedProduct, setSelectedProduct] = useState(null)
  const [productOptions, setProductOptions] = useState({})

  useEffect(() => {
    setIsLoaded(true)
  }, [])

  const filteredProducts = selectedCategory === 'all' 
    ? products 
    : products.filter(product => product.category === selectedCategory)

  const addToCart = (product, options = {}) => {
    const cartItem = {
      ...product,
      ...options,
      cartId: `${product.id}-${Date.now()}`,
      quantity: 1
    }
    setCart(prev => [...prev, cartItem])
    setSelectedProduct(null)
    setProductOptions({})
  }

  const removeFromCart = (cartId) => {
    setCart(prev => prev.filter(item => item.cartId !== cartId))
  }

  const updateQuantity = (cartId, newQuantity) => {
    if (newQuantity === 0) {
      removeFromCart(cartId)
      return
    }
    setCart(prev => prev.map(item => 
      item.cartId === cartId ? { ...item, quantity: newQuantity } : item
    ))
  }

  const getTotalPrice = () => {
    return cart.reduce((total, item) => total + (item.price * item.quantity), 0)
  }

  const handleCheckout = () => {
    // In a real implementation, this would integrate with Stripe
    alert('Checkout functionality would integrate with Stripe here. This is a demo.')
  }

  const openProductModal = (product) => {
    setSelectedProduct(product)
    setProductOptions({})
  }

  const closeProductModal = () => {
    setSelectedProduct(null)
    setProductOptions({})
  }

  return (
    <div className="pt-16 lg:pt-20">
      {/* Header */}
      <section className="section-padding py-16 lg:py-24">
        <div className="container-max">
          <div className={`text-center transform transition-all duration-1000 ${
            isLoaded ? 'translate-y-0 opacity-100' : 'translate-y-8 opacity-0'
          }`}>
            <h1 className="text-4xl md:text-5xl lg:text-6xl font-serif font-bold mb-6">
              Studio Shop
            </h1>
            <p className="text-lg md:text-xl text-gray-600 max-w-3xl mx-auto">
              Discover our curated collection of apparel, art prints, aftercare products, 
              and gift cards. Support the studio and take home a piece of our artistry.
            </p>
          </div>
        </div>
      </section>

      <div className="section-padding">
        <div className="container-max">
          <div className="flex flex-col lg:flex-row gap-8">
            {/* Sidebar */}
            <div className="lg:w-1/4">
              {/* Categories */}
              <div className="bg-white border border-gray-200 rounded-lg p-6 mb-6">
                <h3 className="text-lg font-serif font-bold mb-4">Categories</h3>
                <div className="space-y-2">
                  {categories.map(category => (
                    <button
                      key={category.id}
                      onClick={() => setSelectedCategory(category.id)}
                      className={`w-full text-left px-3 py-2 rounded-lg transition-colors duration-200 ${
                        selectedCategory === category.id
                          ? 'bg-black text-white'
                          : 'text-gray-600 hover:bg-gray-100'
                      }`}
                    >
                      {category.name}
                    </button>
                  ))}
                </div>
              </div>

              {/* Cart */}
              <div className="bg-white border border-gray-200 rounded-lg p-6 sticky top-24">
                <h3 className="text-lg font-serif font-bold mb-4">
                  Cart ({cart.length})
                </h3>
                
                {cart.length === 0 ? (
                  <p className="text-gray-500 text-sm">Your cart is empty</p>
                ) : (
                  <>
                    <div className="space-y-3 mb-4 max-h-64 overflow-y-auto">
                      {cart.map(item => (
                        <div key={item.cartId} className="flex items-center space-x-3 text-sm">
                          <img 
                            src={item.image} 
                            alt={item.name}
                            className="w-12 h-12 object-cover rounded"
                          />
                          <div className="flex-1 min-w-0">
                            <p className="font-medium truncate">{item.name}</p>
                            {item.size && <p className="text-gray-500">Size: {item.size}</p>}
                            {item.color && <p className="text-gray-500">Color: {item.color}</p>}
                            <div className="flex items-center space-x-2 mt-1">
                              <button
                                onClick={() => updateQuantity(item.cartId, item.quantity - 1)}
                                className="w-6 h-6 rounded-full bg-gray-200 flex items-center justify-center text-xs"
                              >
                                -
                              </button>
                              <span className="text-xs">{item.quantity}</span>
                              <button
                                onClick={() => updateQuantity(item.cartId, item.quantity + 1)}
                                className="w-6 h-6 rounded-full bg-gray-200 flex items-center justify-center text-xs"
                              >
                                +
                              </button>
                            </div>
                          </div>
                          <div className="text-right">
                            <p className="font-medium">${(item.price * item.quantity).toFixed(2)}</p>
                            <button
                              onClick={() => removeFromCart(item.cartId)}
                              className="text-red-500 text-xs hover:underline"
                            >
                              Remove
                            </button>
                          </div>
                        </div>
                      ))}
                    </div>
                    
                    <div className="border-t pt-3">
                      <div className="flex justify-between items-center mb-3">
                        <span className="font-semibold">Total:</span>
                        <span className="font-bold text-lg">${getTotalPrice().toFixed(2)}</span>
                      </div>
                      <button
                        onClick={handleCheckout}
                        className="w-full btn-primary text-sm py-2"
                      >
                        Checkout
                      </button>
                    </div>
                  </>
                )}
              </div>
            </div>

            {/* Products Grid */}
            <div className="lg:w-3/4">
              <div className="flex justify-between items-center mb-6">
                <h2 className="text-2xl font-serif font-bold">
                  {categories.find(cat => cat.id === selectedCategory)?.name}
                </h2>
                <p className="text-gray-600">
                  {filteredProducts.length} product{filteredProducts.length !== 1 ? 's' : ''}
                </p>
              </div>

              <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
                {filteredProducts.map(product => (
                  <div key={product.id} className="bg-white border border-gray-200 rounded-lg overflow-hidden hover:shadow-lg transition-shadow duration-300">
                    <div className="relative">
                      <img 
                        src={product.image} 
                        alt={product.name}
                        className="w-full h-64 object-cover"
                      />
                      {!product.inStock && (
                        <div className="absolute inset-0 bg-black bg-opacity-50 flex items-center justify-center">
                          <span className="text-white font-semibold">Out of Stock</span>
                        </div>
                      )}
                    </div>
                    
                    <div className="p-4">
                      <h3 className="font-serif font-bold mb-2">{product.name}</h3>
                      <p className="text-gray-600 text-sm mb-3 line-clamp-2">{product.description}</p>
                      
                      <div className="flex justify-between items-center">
                        <span className="text-xl font-bold">${product.price.toFixed(2)}</span>
                        <button
                          onClick={() => openProductModal(product)}
                          disabled={!product.inStock}
                          className={`px-4 py-2 rounded-lg text-sm font-medium transition-colors duration-200 ${
                            product.inStock
                              ? 'bg-black text-white hover:bg-gray-800'
                              : 'bg-gray-300 text-gray-500 cursor-not-allowed'
                          }`}
                        >
                          {product.inStock ? 'Add to Cart' : 'Out of Stock'}
                        </button>
                      </div>
                    </div>
                  </div>
                ))}
              </div>
            </div>
          </div>
        </div>
      </div>

      {/* Product Modal */}
      {selectedProduct && (
        <div className="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center p-4 z-50">
          <div className="bg-white rounded-lg max-w-md w-full max-h-[90vh] overflow-y-auto">
            <div className="p-6">
              <div className="flex justify-between items-start mb-4">
                <h3 className="text-xl font-serif font-bold">{selectedProduct.name}</h3>
                <button
                  onClick={closeProductModal}
                  className="text-gray-500 hover:text-gray-700"
                >
                  <svg className="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
                  </svg>
                </button>
              </div>
              
              <img 
                src={selectedProduct.image} 
                alt={selectedProduct.name}
                className="w-full h-64 object-cover rounded-lg mb-4"
              />
              
              <p className="text-gray-600 mb-4">{selectedProduct.description}</p>
              
              {/* Size Selection */}
              {selectedProduct.sizes && (
                <div className="mb-4">
                  <label className="block text-sm font-medium text-gray-700 mb-2">Size</label>
                  <div className="flex flex-wrap gap-2">
                    {selectedProduct.sizes.map(size => (
                      <button
                        key={size}
                        onClick={() => setProductOptions(prev => ({ ...prev, size }))}
                        className={`px-3 py-1 border rounded-lg text-sm ${
                          productOptions.size === size
                            ? 'border-black bg-black text-white'
                            : 'border-gray-300 hover:border-gray-400'
                        }`}
                      >
                        {size}
                      </button>
                    ))}
                  </div>
                </div>
              )}
              
              {/* Color Selection */}
              {selectedProduct.colors && (
                <div className="mb-4">
                  <label className="block text-sm font-medium text-gray-700 mb-2">Color</label>
                  <div className="flex flex-wrap gap-2">
                    {selectedProduct.colors.map(color => (
                      <button
                        key={color}
                        onClick={() => setProductOptions(prev => ({ ...prev, color }))}
                        className={`px-3 py-1 border rounded-lg text-sm ${
                          productOptions.color === color
                            ? 'border-black bg-black text-white'
                            : 'border-gray-300 hover:border-gray-400'
                        }`}
                      >
                        {color}
                      </button>
                    ))}
                  </div>
                </div>
              )}
              
              <div className="flex justify-between items-center pt-4 border-t">
                <span className="text-2xl font-bold">${selectedProduct.price.toFixed(2)}</span>
                <button
                  onClick={() => addToCart(selectedProduct, productOptions)}
                  className="btn-primary"
                >
                  Add to Cart
                </button>
              </div>
            </div>
          </div>
        </div>
      )}

      {/* Shipping Info */}
      <section className="section-padding py-16 bg-gray-50">
        <div className="container-max">
          <div className="max-w-4xl mx-auto">
            <h2 className="text-3xl font-serif font-bold text-center mb-12">
              Shipping & Returns
            </h2>
            
            <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
              <div className="text-center">
                <div className="w-16 h-16 bg-black text-white rounded-full flex items-center justify-center mx-auto mb-4">
                  <svg className="w-8 h-8" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M20 7l-8-4-8 4m16 0l-8 4m8-4v10l-8 4m0-10L4 7m8 4v10M4 7v10l8 4" />
                  </svg>
                </div>
                <h3 className="text-lg font-serif font-bold mb-2">Free Shipping</h3>
                <p className="text-gray-600">Free shipping on orders over $50 within the continental US</p>
              </div>
              
              <div className="text-center">
                <div className="w-16 h-16 bg-black text-white rounded-full flex items-center justify-center mx-auto mb-4">
                  <svg className="w-8 h-8" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M4.318 6.318a4.5 4.5 0 000 6.364L12 20.364l7.682-7.682a4.5 4.5 0 00-6.364-6.364L12 7.636l-1.318-1.318a4.5 4.5 0 00-6.364 0z" />
                  </svg>
                </div>
                <h3 className="text-lg font-serif font-bold mb-2">Easy Returns</h3>
                <p className="text-gray-600">30-day return policy on unworn apparel and unopened products</p>
              </div>
              
              <div className="text-center">
                <div className="w-16 h-16 bg-black text-white rounded-full flex items-center justify-center mx-auto mb-4">
                  <svg className="w-8 h-8" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 12l2 2 4-4m5.618-4.016A11.955 11.955 0 0112 2.944a11.955 11.955 0 01-8.618 3.04A12.02 12.02 0 003 9c0 5.591 3.824 10.29 9 11.622 5.176-1.332 9-6.03 9-11.622 0-1.042-.133-2.052-.382-3.016z" />
                  </svg>
                </div>
                <h3 className="text-lg font-serif font-bold mb-2">Secure Checkout</h3>
                <p className="text-gray-600">SSL encrypted checkout powered by Stripe for secure payments</p>
              </div>
            </div>
          </div>
        </div>
      </section>
    </div>
  )
}

export default Shop